@@ -4,7 +4,7 @@ Get information from the user
 
 import collections
 
-from .. import errors
+from .. import errors, utils
 from . import JobBase
 
 import logging  # isort:skip
@@ -20,8 +20,8 @@ class ChoiceJob(JobBase):
 
         ``dialog_updated``
             Emitted when the :attr:`choices` or :attr:`focused` properties are
-            set. Registered callbacks get the job instance as a positional
-            argument.
+            set or when :attr:`choices` is modified. Registered callbacks get
+            the job instance as a positional argument.
 
         ``chosen``
             Emitted when the :attr:`choice` property is set or when the job's
@@ -50,14 +50,15 @@ class ChoiceJob(JobBase):
         Choices may also be passed as a flat iterable of :class:`str`, in which
         case both items in the tuple are identical.
 
-        When setting this property, focus is preserved if the focused choice
-        exists in the new sequence of choices. Otherwise, the first choice is
+        When setting this property, focus is preserved if the value of the
+        focused choice exists in the new choices. Otherwise, the first choice is
         focused.
         """
         return getattr(self, '_choices', ())
 
     @choices.setter
     def choices(self, choices):
+        # Build new list of choices
         valid_choices = []
         for choice in choices:
             if isinstance(choice, str):
@@ -73,12 +74,23 @@ class ChoiceJob(JobBase):
         if len(valid_choices) < 2:
             raise ValueError(f'There must be at least 2 choices: {choices!r}')
 
+        # Remember current focus
         prev_focused = self.focused
-        self._choices = tuple(valid_choices)
-        if prev_focused in valid_choices:
-            self._focused_index = valid_choices.index(prev_focused)
-        else:
-            self._focused_index = 0
+
+        # Set new choices
+        self._choices = utils.MonitoredList(
+            valid_choices,
+            callback=lambda _: self.signal.emit('dialog_updated', self),
+        )
+
+        # Try to restore focus
+        self._focused_index = 0
+        if prev_focused:
+            prev_label, prev_value = prev_focused
+            for index, (label, value) in enumerate(valid_choices):
+                if value == prev_value:
+                    self._focused_index = index
+                    break
 
         self.signal.emit('dialog_updated', self)
 
@@ -171,6 +183,25 @@ class ChoiceJob(JobBase):
         else:
             raise ValueError(f'Invalid choice: {choice!r}')
 
+    def set_label(self, identifier, new_label):
+        """
+        Assign new label to choice
+
+        :param identifier: Choice (2-tuple of (<current label>, <value>) or the
+            current label or value of a choice
+        :param new_label: New label for the choice defined by `identifier`
+
+        Do nothing if `identifier` doesn't match any choice.
+        """
+        new_choices = []
+        for label, value in tuple(self.choices):
+            if identifier == label or identifier == value or identifier == (label, value):
+                new_choices.append((str(new_label), value))
+            else:
+                new_choices.append((label, value))
+        if self.choices != new_choices:
+            self.choices = new_choices
+
     def initialize(self, *, name, label, choices, focused=None):
         """
         Set internal state
