@@ -6,7 +6,8 @@ import abc
 import builtins
 
 from .. import jobs
-from ..utils import btclients, cached_property, fs, signal, types, webdbs
+from ..utils import (btclients, cached_property, fs, release, signal, types,
+                     webdbs)
 
 import logging  # isort:skip
 _log = logging.getLogger(__name__)
@@ -274,13 +275,45 @@ class TrackerJobsBase(abc.ABC):
     def finalize_copy_torrent_job(self, _):
         self.copy_torrent_job.finalize()
 
+    @cached_property
+    def release_name(self):
+        """
+        :class:`~.release.ReleaseName` instance with
+        :attr:`release_name_translation` applied
+        """
+        return release.ReleaseName(
+            path=self.content_path,
+            translate=self.release_name_translation,
+        )
+
+    release_name_translation = {}
+    """See ``translate`` argument of :attr:`~.utils.release.ReleaseName`"""
+
     @cached_property
     def release_name_job(self):
-        """:class:`~.jobs.release_name.ReleaseNameJob` instance"""
-        return jobs.release_name.ReleaseNameJob(
-            content_path=self.content_path,
+        """
+        :class:`~.jobs.dialog.TextFieldJob` instance with text set to
+        :attr:`release_name`
+
+        The text is automatically updated when :attr:`imdb_job` sends an ID.
+        """
+        job = jobs.dialog.TextFieldJob(
+            name='release-name',
+            label='Release Name',
+            text=str(self.release_name),
             **self.common_job_args,
         )
+        # Automatically update release_name with user-confirmed release name
+        job.signal.register('output', self.release_name.set_release_info)
+        return job
+
+    def _update_release_name(self, imdb_id):
+        self.release_name_job.add_task(
+            self.release_name_job.fetch_text(
+                coro=self.release_name.fetch_info(imdb_id),
+                error_is_fatal=False,
+            ),
+        )
 
     @cached_property
     def imdb_job(self):
@@ -291,7 +324,7 @@ class TrackerJobsBase(abc.ABC):
             **self.common_job_args,
         )
         # Update release name with IMDb data
-        imdb_job.signal.register('output', self.release_name_job.fetch_info)
+        imdb_job.signal.register('output', self._update_release_name)
         return imdb_job
 
     @cached_property
@@ -312,9 +345,6 @@ class TrackerJobsBase(abc.ABC):
             **self.common_job_args,
         )
 
-    screenshots = 2
-    """Number of screenshots to make"""
-
     @cached_property
     def screenshots_job(self):
         """
@@ -325,7 +355,7 @@ class TrackerJobsBase(abc.ABC):
         """
         return jobs.screenshots.ScreenshotsJob(
             content_path=self.content_path,
-            count=self.options.get('screenshots') or self.screenshots,
+            count=self.options.get('screenshots'),
             **self.common_job_args,
         )
 
