@@ -640,6 +640,7 @@ class BbTrackerJobs(TrackerJobsBase):
         #                      "SD"
         width = video.width(self.content_path)
         height = video.height(self.content_path)
+        _log.debug('WTFSD: width=%r, height=%r', width, height)
         if 0 < width < 700 and 0 < height < 460:
             return 'SD'
 
@@ -671,13 +672,14 @@ class BbTrackerJobs(TrackerJobsBase):
             return 'REPACK'
 
     @property
-    def release_info_hdr10(self):
-        if video.is_hdr10(self.content_path):
-            return 'HDR10'
+    def release_info_hdr_format(self):
+        hdr_format = video.hdr_format(self.content_path)
+        if hdr_format:
+            return hdr_format
 
     @property
     def release_info_10bit(self):
-        if video.bit_depth(self.content_path) == '10' and not self.release_info_hdr10:
+        if video.bit_depth(self.content_path) == '10':
             return '10-bit'
 
     @property
@@ -798,8 +800,8 @@ class BbTrackerJobs(TrackerJobsBase):
 
             # Special formats
             self.release_info_remux,
-            self.release_info_hdr10,
             self.release_info_10bit,
+            self.release_info_hdr_format,
 
             # Editions
             self.release_info_uncensored,
@@ -893,8 +895,8 @@ class BbTrackerJobs(TrackerJobsBase):
             # Special formats
             self.release_info_remux,
             self.release_info_576p_PAL,
-            self.release_info_hdr10,
             self.release_info_10bit,
+            self.release_info_hdr_format,
 
             # Editions
             self.release_info_uncensored,
