@@ -4,9 +4,10 @@ Concrete :class:`~.base.TrackerJobsBase` subclass for BHD
 
 import io
 import os
+import re
 
 from ... import jobs
-from ...utils import as_groups, cached_property, fs, release
+from ...utils import as_groups, cached_property, release
 from ..base import TrackerJobsBase
 
 import logging  # isort:skip
@@ -14,32 +15,12 @@ _log = logging.getLogger(__name__)
 
 
 class BhdTrackerJobs(TrackerJobsBase):
-    @cached_property
-    def guessed_release_name(self):
-        return release.ReleaseName(self.content_path)
-
-    @property
-    def approved_release_name(self):
-        if self.release_name_job.is_finished and self.release_name_job.output:
-            if not hasattr(self, '_approved_release_name'):
-                release_name = self.get_job_output(self.release_name_job, slice=0)
-                link_path = os.path.join(self.release_name_job.home_directory, release_name)
-                file_extension = fs.file_extension(self.content_path)
-                if file_extension:
-                    link_path += f'.{file_extension}'
-                if not os.path.exists(link_path):
-                    os.symlink(os.path.abspath(self.content_path), link_path)
-                self._approved_release_name = release.ReleaseName(link_path)
-            return self._approved_release_name
-
-    movie_types = (release.ReleaseType.movie,)
-    series_types = (release.ReleaseType.season, release.ReleaseType.episode)
-
-    def is_movie_type(self, type):
-        return type in self.movie_types
-
-    def is_series_type(self, type):
-        return type in self.series_types
+    release_name_translation = {
+        'audio_format': {
+            re.compile(r'^AC-3$'): r'DD',
+            re.compile(r'^E-AC-3$'): r'DD+',
+        },
+    }
 
     @cached_property
     def jobs_before_upload(self):
@@ -55,22 +36,22 @@ class BhdTrackerJobs(TrackerJobsBase):
                 job.condition = self.make_job_condition(job_attr)
 
         return (
-            # Background jobs
-            self.create_torrent_job,
-            self.mediainfo_job,
-            self.screenshots_job,
-            self.upload_screenshots_job,
-
             # Interactive jobs
-            self.category_job,
             self.imdb_job,
             self.tmdb_job,
             self.release_name_job,
+            self.category_job,
             self.type_job,
             self.source_job,
             self.description_job,
             self.scene_check_job,
             self.tags_job,
+
+            # Background jobs
+            self.create_torrent_job,
+            self.mediainfo_job,
+            self.screenshots_job,
+            self.upload_screenshots_job,
         )
 
     def make_job_condition(self, job_attr):
@@ -90,21 +71,43 @@ class BhdTrackerJobs(TrackerJobsBase):
 
     @cached_property
     def category_job(self):
+        # 'output' signal is only emitted when job succeeds while 'finished'
+        # signal is also emitted when job fails (e.g. when Ctrl-c is pressed)
+        self.release_name_job.signal.register('output', self.autodetect_category)
         return self.make_choice_job(
             name='category',
             label='Category',
             condition=self.make_job_condition('category_job'),
-            autodetected=self.guessed_release_name.type,
-            autofinish=False,
             options=(
-                {'label': 'Movie', 'value': '1', 'match': self.is_movie_type},
-                {'label': 'TV', 'value': '2', 'match': self.is_series_type},
+                {'label': 'Movie', 'value': '1'},
+                {'label': 'TV', 'value': '2'},
             ),
         )
 
+    _autodetect_category_map = {
+        'Movie': lambda release_name: release_name.type is release.ReleaseType.movie,
+        'TV': lambda release_name: release_name.type in (release.ReleaseType.season,
+                                                         release.ReleaseType.episode)
+    }
+
+    def autodetect_category(self, _):
+        approved_release_name = self.release_name
+        _log.debug('Autodetecting category: Approved release type: %r', approved_release_name.type)
+        for label, is_match in self._autodetect_category_map.items():
+            if is_match(approved_release_name):
+                # Focus autodetected choice
+                self.category_job.focused = label
+                # Get value of autodetected choice
+                value = self.category_job.focused[1]
+                # Mark autodetected choice
+                self.category_job.set_label(value, f'{label} (autodetected)')
+                break
+
     @cached_property
     def type_job(self):
-        self.release_name_job.signal.register('finished', self.autodetect_type)
+        # 'output' signal is only emitted when job succeeds while 'finished'
+        # signal is also emitted when job fails (e.g. when Ctrl-c is pressed)
+        self.release_name_job.signal.register('output', self.autodetect_type)
         return self.make_choice_job(
             name='type',
             label='Type',
@@ -132,7 +135,6 @@ class BhdTrackerJobs(TrackerJobsBase):
             ),
         )
 
-    # Map type_job labels to matchers
     _autodetect_type_map = {
         'DVD 9': lambda release_name: release_name.source == 'DVD9',
         'DVD 5': lambda release_name: release_name.source == 'DVD5',
@@ -147,22 +149,26 @@ class BhdTrackerJobs(TrackerJobsBase):
     }
 
     def autodetect_type(self, _):
-        if self.approved_release_name:
-            approved_release_name = self.approved_release_name
-            _log.debug('Approved resolution and source: %r, %r',
-                       approved_release_name.resolution, approved_release_name.source)
-            for label, is_match in self._autodetect_type_map.items():
-                if is_match(approved_release_name):
-                    self.type_job.focused = label
-                    value = self.type_job.focused[1]
-                    self.type_job.set_label(value, f'{label} (autodetected)')
-                    break
-            else:
-                self.type_job.focused = 'Other'
+        approved_release_name = self.release_name
+        _log.debug('Autodetecting type: Approved resolution: %r', approved_release_name.resolution)
+        _log.debug('Autodetecting type: Approved source: %r', approved_release_name.source)
+        for label, is_match in self._autodetect_type_map.items():
+            if is_match(approved_release_name):
+                # Focus autodetected choice
+                self.type_job.focused = label
+                # Get value of autodetected choice
+                value = self.type_job.focused[1]
+                # Mark autodetected choice
+                self.type_job.set_label(value, f'{label} (autodetected)')
+                break
+        else:
+            self.type_job.focused = 'Other'
 
     @cached_property
     def source_job(self):
-        self.release_name_job.signal.register('finished', self.autodetect_source)
+        # 'output' signal is only emitted when job succeeds while 'finished'
+        # signal is also emitted when job fails (e.g. when Ctrl-c is pressed)
+        self.release_name_job.signal.register('output', self.autodetect_source)
         return self.make_choice_job(
             name='source',
             label='Source',
@@ -185,21 +191,20 @@ class BhdTrackerJobs(TrackerJobsBase):
         'DVD': lambda release_name: 'DVD' in release_name.source,
     }
 
-    def autodetect_source(self, release_name_job):
-        if self.approved_release_name:
-            approved_release_name = self.approved_release_name
-            _log.debug('Approved source: %r', approved_release_name.source)
-            for label, is_match in self._autodetect_source_map.items():
-                if is_match(approved_release_name):
-                    # Focus autodetected choice
-                    self.source_job.focused = label
-                    # Get value of autodetected choice
-                    value = self.source_job.focused[1]
-                    # Mark autodetected choice
-                    self.source_job.set_label(value, f'{label} (autodetected)')
-                    # Select autodetected choice (i.e. finish job)
-                    self.source_job.choice = value
-                    break
+    def autodetect_source(self, _):
+        approved_release_name = self.release_name
+        _log.debug('Autodetecting source: Approved source: %r', approved_release_name.source)
+        for label, is_match in self._autodetect_source_map.items():
+            if is_match(approved_release_name):
+                # Focus autodetected choice
+                self.source_job.focused = label
+                # Get value of autodetected choice
+                value = self.source_job.focused[1]
+                # Mark autodetected choice
+                self.source_job.set_label(value, f'{label} (autodetected)')
+                # Select autodetected choice (i.e. finish job)
+                self.source_job.choice = value
+                break
 
     @cached_property
     def description_job(self):
@@ -218,9 +223,6 @@ class BhdTrackerJobs(TrackerJobsBase):
         )
         return job
 
-    screenshots = 4
-    """How many screenshots to make"""
-
     image_host_config = {
         'imgbox': {'thumb_width': 350},
     }
@@ -236,7 +238,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         rows = []
         screenshot_groups = as_groups(
             self.upload_screenshots_job.uploaded_images,
-            group_sizes=(2, 3),
+            group_sizes=(2,),
             default='PLACEHOLDER',
         )
         for screenshots in screenshot_groups:
@@ -275,17 +277,17 @@ class BhdTrackerJobs(TrackerJobsBase):
         # OpenMatte, 2D3D, WEBRip, WEBDL, 3D, 4kRemaster, DualAudio, EnglishDub,
         # Personal, Scene, DigitalExtras, Extras)
         tags = []
-        if 'WEBRip' in self.approved_release_name.source:
+        if 'WEBRip' in self.release_name.source:
             tags.append('WEBRip')
-        elif 'WEB-DL' in self.approved_release_name.source:
+        elif 'WEB-DL' in self.release_name.source:
             tags.append('WEBDL')
-        if 'Hybrid' in self.approved_release_name.source:
+        if 'Hybrid' in self.release_name.source:
             tags.append('Hybrid')
-        if self.approved_release_name.has_commentary:
+        if self.release_name.has_commentary:
             tags.append('Commentary')
-        if self.approved_release_name.has_dual_audio:
+        if self.release_name.has_dual_audio:
             tags.append('DualAudio')
-        if 'Open Matte' in self.approved_release_name.edition:
+        if 'Open Matte' in self.release_name.edition:
             tags.append('OpenMatte')
         if self.get_job_attribute(self.scene_check_job, 'is_scene_release'):
             tags.append('Scene')
@@ -338,27 +340,21 @@ class BhdTrackerJobs(TrackerJobsBase):
     def post_data_edition(self):
         # The edition of the uploaded release. (Collector, Director, Extended,
         # Limited, Special, Theatrical, Uncut or Unrated)
-        edition = self.approved_release_name.edition
+        edition = self.release_name.edition
         _log.debug('Approved edition: %r', edition)
-
-        # TODO: Submitting any of the commented edition values produces the
-        #       error "Invalid edition value: Field must be a valid edition
-        #       value."
-        #       "Uncut" and "Unrated" work
-
-        # if 'Collector' in edition:
-        #     return 'Collector'
-        # # elif 'DC' in edition or 'Director' in edition:
-        # #     return 'Director'
-        # elif 'Extended' in edition:
-        #     return 'Extended'
-        # elif 'Limited' in edition:
-        #     return 'Limited'
-        # elif 'Special' in edition:
-        #     return 'Special'
-        # elif 'Theatrical' in edition:
-        #     return 'Theatrical'
-        if 'Uncut' in edition:
+        if 'Collector' in edition:
+            return 'Collector'
+        elif 'DC' in edition or 'Director' in edition:
+            return 'Director'
+        elif 'Extended' in edition:
+            return 'Extended'
+        elif 'Limited' in edition:
+            return 'Limited'
+        elif 'Special' in edition:
+            return 'Special'
+        elif 'Theatrical' in edition:
+            return 'Theatrical'
+        elif 'Uncut' in edition:
             return 'Uncut'
         elif 'Unrated' in edition:
             return 'Unrated'
@@ -367,7 +363,7 @@ class BhdTrackerJobs(TrackerJobsBase):
     def post_data_pack(self):
         # The TV pack flag for when the torrent contains a complete season.
         # (0 = No TV pack or 1 = TV Pack). Default is 0
-        if self.approved_release_name.type is release.ReleaseType.season:
+        if self.release_name.type is release.ReleaseType.season:
             return '1'
         else:
             return '0'
@@ -377,7 +373,7 @@ class BhdTrackerJobs(TrackerJobsBase):
         # The SD flag. (0 = Not Standard Definition, 1 = Standard Definition).
         # Default is 0
         try:
-            height = int(self.approved_release_name.resolution[:-1])
+            height = int(self.release_name.resolution[:-1])
         except ValueError:
             return '0'
         else:
@@ -398,16 +394,13 @@ class BhdTrackerJobs(TrackerJobsBase):
                             with open(nfo_path, 'r') as f:
                                 return f.read()
                         except OSError as e:
-                            if e.strerror:
-                                self.error(e.strerror)
-                            else:
-                                self.error(e)
+                            self.error(e.strerror if e.strerror else str(e))
 
     @property
     def post_data_special(self):
         # The TV special flag for when the torrent contains a TV special. (0 =
         # Not a TV special, 1 = TV Special). Default is 0
-        if self.approved_release_name.type is release.ReleaseType.episode:
+        if self.release_name.type is release.ReleaseType.episode:
             if self.options['special']:
                 return '1'
         return '0'
