@@ -32,31 +32,111 @@ logging.getLogger('rebulk').setLevel(logging.WARNING)
 _guessit = LazyModule(module='guessit.api', name='_guessit', namespace=globals())
 
 
+class _translated_property:
+    def __init__(self, fget=None, fset=None, fdel=None, doc=None):
+        self.name = fget.__name__
+        self.fget = fget
+        self.fset = fset
+        self.fdel = fdel
+        if doc is None and fget is not None:
+            doc = fget.__doc__
+        self.__doc__ = doc
+
+    def __get__(self, obj, objtype=None):
+        if obj is None:
+            return self
+        else:
+            value = self.fget(obj)
+            return self._translate(value, obj._translate)
+
+    def _translate(self, value, tables):
+        def translate(string):
+            table = tables.get(self.name, {})
+            for regex, replacement in table.items():
+                string = regex.sub(replacement, string)
+            return string
+
+        if isinstance(value, str):
+            value = translate(value)
+        elif isinstance(value, collections.abc.Iterable):
+            value[:] = [translate(v) for v in value]
+
+        return value
+
+    def __set__(self, obj, value):
+        if self.fset is None:
+            raise AttributeError("Can't set attribute")
+        self.fset(obj, value)
+
+    def __delete__(self, obj):
+        raise AttributeError("Can't delete attribute")
+
+    def getter(self, fget):
+        return type(self)(fget, self.fset, self.fdel, self.__doc__)
+
+    def setter(self, fset):
+        return type(self)(self.fget, fset, self.fdel, self.__doc__)
+
+
 class ReleaseName(collections.abc.Mapping):
     """
     Standardized release name
 
-    :param str path: Path to release content
+    :param str path: Path to release file or directory
 
-    If `path` exists, it is used to analyze file contents for some parts of the
-    new release name, e.g. to detect the resolution.
+        If `path` exists, it is used to read video and audio metadata, e.g. to
+        detect the codecs, resolution, etc.
+
+    :param str name: Path or other string to pass to :class:`ReleaseInfo`
+        (defaults to `path`)
+
+    :param dict translate: Map names of properties that return a string
+        (e.g. ``audio_format``) to maps of regular expressions to replacement
+        strings. The replacement strings may contain backreferences to groups in
+        their regular expression.
+
+        Example:
+
+        >>> {
+        >>>     'audio_format': {
+        >>>         re.compile(r'^AC-3$'): r'DD',
+        >>>         re.compile(r'^E-AC-3$'): r'DD+',
+        >>>     },
+        >>>     'video_format': {
+        >>>         re.compile(r'^x26([45])$'): r'H.26\1',
+        >>>     },
+        >>> }
 
     Example:
 
-    >>> rn = ReleaseName("The.Foo.1984.1080p.Blu-ray.X264-ASDF")
+    >>> rn = ReleaseName("path/to/The.Foo.1984.1080p.Blu-ray.X264-ASDF")
     >>> rn.source
     'BluRay'
     >>> rn.format()
     'The Foo 1984 1080p BluRay DTS x264-ASDF'
-    >>> "{title} ({year})".format(**rn)
-    'The Foo (1984)'
+    >>> "{title} ({year}) [{group}]".format(**rn)
+    'The Foo (1984) [ASDF]'
+    >>> rn.set_name('The Foo 1985 1080p BluRay DTS x264-AsdF')
+    >>> "{title} ({year}) [{group}]".format(**rn)
+    'The Foo (1985) [AsdF]'
     """
 
-    def __init__(self, path):
+    def __init__(self, path, name=None, translate=None):
         self._path = str(path)
-        self._info = ReleaseInfo(self._path)
+        self._name = name
+        self._info = ReleaseInfo(str(name) if name is not None else self._path)
+        self._translate = translate or {}
         self._imdb = webdbs.imdb.ImdbApi()
 
+    def set_release_info(self, path):
+        """
+        Update internal :class:`ReleaseInfo` instance
+
+        :param path: Argument for :class:`ReleaseInfo` (path or any other
+            string)
+        """
+        self._info = ReleaseInfo(str(path))
+
     def _tracks(self):
         # Ignore non-existing files and other file system issues
         try:
@@ -65,7 +145,16 @@ class ReleaseName(collections.abc.Mapping):
             return {}
 
     def __repr__(self):
-        return f'{type(self).__name__}({self._path!r})'
+        posargs = [self._path]
+        kwargs = {}
+        if self._name is not None:
+            kwargs['name'] = self._name
+        if self._translate:
+            kwargs['translate'] = self._translate
+        args = ', '.join(repr(arg) for arg in posargs)
+        if kwargs:
+            args += ', ' + ', '.join(f'{k}={v!r}' for k, v in kwargs.items())
+        return f'{type(self).__name__}({args})'
 
     def __str__(self):
         return self.format()
@@ -78,12 +167,12 @@ class ReleaseName(collections.abc.Mapping):
         cls = type(self)
         return iter(attr for attr in dir(self)
                     if (not attr.startswith('_')
-                        and isinstance(getattr(cls, attr), property)))
+                        and isinstance(getattr(cls, attr), (property, _translated_property))))
 
     def __getitem__(self, name):
         if not isinstance(name, str):
             raise TypeError(f'Not a string: {name!r}')
-        elif isinstance(getattr(type(self), name), property):
+        elif isinstance(getattr(type(self), name, None), (property, _translated_property)):
             return getattr(self, name)
         else:
             raise KeyError(name)
@@ -104,7 +193,7 @@ class ReleaseName(collections.abc.Mapping):
         else:
             self._info['type'] = ReleaseType(value)
 
-    @property
+    @_translated_property
     def title(self):
         """
         Original name of movie or series or "UNKNOWN_TITLE"
@@ -117,7 +206,7 @@ class ReleaseName(collections.abc.Mapping):
     def title(self, value):
         self._info['title'] = str(value)
 
-    @property
+    @_translated_property
     def title_aka(self):
         """
         Alternative name of movie or series or empty string
@@ -137,7 +226,7 @@ class ReleaseName(collections.abc.Mapping):
     def title_aka(self, value):
         self._info['aka'] = str(value)
 
-    @property
+    @_translated_property
     def title_with_aka(self):
         """Combination of :attr:`title` and :attr:`title_aka`"""
         if self.title_aka:
@@ -145,7 +234,7 @@ class ReleaseName(collections.abc.Mapping):
         else:
             return self.title
 
-    @property
+    @_translated_property
     def title_with_aka_and_year(self):
         """
         Combination of :attr:`title`, :attr:`title_aka` and :attr:`year`
@@ -156,14 +245,12 @@ class ReleaseName(collections.abc.Mapping):
 
         :attr:`title_aka` is appended if it is truthy.
         """
-        title = [self.title]
-        if self.title_aka:
-            title.extend(('AKA', self.title_aka))
+        title = [self.title_with_aka]
         if self.year_required:
             title.append(self.year)
         return ' '.join(title)
 
-    @property
+    @_translated_property
     def year(self):
         """
         Release year or "UNKNOWN_YEAR" for movies, empty string for series unless
@@ -192,7 +279,7 @@ class ReleaseName(collections.abc.Mapping):
     @property
     def year_required(self):
         """
-        Whether :attr:`title_full` includes :attr:`year`
+        Whether :attr:`title_with_aka_and_year` includes :attr:`year`
 
         See also :meth:`fetch_info`.
         """
@@ -203,7 +290,7 @@ class ReleaseName(collections.abc.Mapping):
     def year_required(self, value):
         self._year_required = bool(value)
 
-    @property
+    @_translated_property
     def episodes(self):
         """
         Season and episodes in "S01E02"-style format or "UNKNOWN_SEASON" for season
@@ -239,7 +326,7 @@ class ReleaseName(collections.abc.Mapping):
         else:
             self._info['episodes'] = Episodes()
 
-    @property
+    @_translated_property
     def episode_title(self):
         """Episode title if :attr:`type` is "episode" or empty string"""
         if self.type is ReleaseType.episode:
@@ -251,7 +338,7 @@ class ReleaseName(collections.abc.Mapping):
     def episode_title(self, value):
         self._info['episode_title'] = str(value)
 
-    @property
+    @_translated_property
     def service(self):
         """Streaming service abbreviation (e.g. "AMZN", "NF") or empty string"""
         return self._info.get('service') or ''
@@ -260,21 +347,29 @@ class ReleaseName(collections.abc.Mapping):
     def service(self, value):
         self._info['service'] = str(value)
 
-    @property
+    @_translated_property
     def edition(self):
         """List of "Director's Cut", "Uncut", "Unrated", etc"""
         if 'edition' not in self._info:
             self._info['edition'] = []
+
+        # Dual Audio
         if 'Dual Audio' not in self._info['edition']:
             if self.has_dual_audio:
                 self._info['edition'].append('Dual Audio')
+
+        # HDR format (e.g. "Dolby Vision" or "HDR10")
+        if not any(hdr in self._info['edition'] for hdr in video.hdr_formats):
+            if self.hdr_format:
+                self._info['edition'].append(self.hdr_format)
+
         return self._info['edition']
 
     @edition.setter
     def edition(self, value):
         self._info['edition'] = [str(v) for v in value]
 
-    @property
+    @_translated_property
     def source(self):
         '''Original source (e.g. "BluRay", "WEB-DL") or "UNKNOWN_SOURCE"'''
         return self._info.get('source') or 'UNKNOWN_SOURCE'
@@ -283,7 +378,7 @@ class ReleaseName(collections.abc.Mapping):
     def source(self, value):
         self._info['source'] = str(value)
 
-    @property
+    @_translated_property
     def resolution(self):
         '''Resolution (e.g. "1080p") or "UNKNOWN_RESOLUTION"'''
         res = video.resolution(self._path)
@@ -295,7 +390,7 @@ class ReleaseName(collections.abc.Mapping):
     def resolution(self, value):
         self._info['resolution'] = str(value)
 
-    @property
+    @_translated_property
     def audio_format(self):
         '''Audio format or "UNKNOWN_AUDIO_FORMAT"'''
         af = video.audio_format(self._path)
@@ -307,7 +402,7 @@ class ReleaseName(collections.abc.Mapping):
     def audio_format(self, value):
         self._info['audio_codec'] = str(value)
 
-    @property
+    @_translated_property
     def audio_channels(self):
         """Audio channels (e.g. "5.1") or empty string"""
         ac = video.audio_channels(self._path)
@@ -319,7 +414,7 @@ class ReleaseName(collections.abc.Mapping):
     def audio_channels(self, value):
         self._info['audio_channels'] = str(value)
 
-    @property
+    @_translated_property
     def video_format(self):
         '''Video format (or encoder in case of x264/x265/XviD) or "UNKNOWN_VIDEO_FORMAT"'''
         vf = video.video_format(self._path)
@@ -331,7 +426,7 @@ class ReleaseName(collections.abc.Mapping):
     def video_format(self, value):
         self._info['video_codec'] = str(value)
 
-    @property
+    @_translated_property
     def group(self):
         '''Name of release group or "NOGROUP"'''
         return self._info.get('group') or 'NOGROUP'
@@ -356,16 +451,13 @@ class ReleaseName(collections.abc.Mapping):
         above.
         """
         # Use manually set value unless it is None
-        if hasattr(self, '_has_commentary') and self._has_commentary is not None:
+        if getattr(self, '_has_commentary', None) is not None:
             return self._has_commentary
 
         # Find "Commentary" in audio track titles
         elif os.path.exists(self._path):
-            tracks = self._tracks()
-            for track in tracks.get('Audio', {}):
-                if 'commentary' in track.get('Title', '').lower():
-                    return True
-            return False
+            self._has_commentary = bool(video.has_commentary(self._path))
+            return self._has_commentary
 
         # Default to ReleaseInfo['has_commentary']
         else:
@@ -374,15 +466,14 @@ class ReleaseName(collections.abc.Mapping):
     @has_commentary.setter
     def has_commentary(self, value):
         if value is None:
-            self._has_commentary = value
+            self._has_commentary = None
         else:
             self._has_commentary = bool(value)
 
     @property
     def has_dual_audio(self):
         """
-        Whether this release has an English and a non-English, original language
-        audio track
+        Whether this release has an English and a non-English audio track
 
         If not set explicitly and the given `path` exists, this value is
         autodetected if possible, otherwise default to whatever
@@ -392,7 +483,7 @@ class ReleaseName(collections.abc.Mapping):
         above.
         """
         # Use manually set value unless it is None
-        if hasattr(self, '_has_dual_audio') and self._has_dual_audio is not None:
+        if getattr(self, '_has_dual_audio', None) is not None:
             return self._has_dual_audio
 
         # Autodetect dual audio
@@ -400,17 +491,57 @@ class ReleaseName(collections.abc.Mapping):
             self._has_dual_audio = bool(video.has_dual_audio(self._path))
             return self._has_dual_audio
 
-        # Default to ReleaseInfo['has_dual_audio']
+        # Default to ReleaseInfo['edition']
         else:
             return 'Dual Audio' in self._info.get('edition', ())
 
     @has_dual_audio.setter
     def has_dual_audio(self, value):
         if value is None:
-            self._has_dual_audio = value
+            self._has_dual_audio = None
         else:
             self._has_dual_audio = bool(value)
 
+    @_translated_property
+    def hdr_format(self):
+        """
+        HDR format name (e.g. "Dolby Vision" or "HDR10")
+
+        If not set explicitly and the given `path` exists, this value is
+        autodetected if possible, otherwise default to whatever
+        :class:`ReleaseInfo` detected in the release name.
+
+        Setting this value back to `None` turns on autodetection as described
+        above.
+        """
+        # Use manually set value unless it is None
+        if getattr(self, '_hdr_format', None) is not None:
+            return self._hdr_format
+
+        # Autodetect
+        if os.path.exists(self._path):
+            hdr_format = video.hdr_format(self._path)
+            if hdr_format:
+                self._hdr_format = hdr_format
+                return self._hdr_format
+
+        # Default to ReleaseInfo['edition']
+        guessed_editions = self._info.get('edition', ())
+        for hdr_format in video.hdr_formats:
+            if hdr_format in guessed_editions:
+                return hdr_format
+
+    @hdr_format.setter
+    def hdr_format(self, value):
+        if value is None:
+            self._hdr_format = None
+        elif value == '':
+            self._hdr_format = ''
+        elif value in video.hdr_formats:
+            self._hdr_format = str(value)
+        else:
+            raise ValueError(f'Unknown HDR format: {value!r}')
+
     _needed_attrs = {
         ReleaseType.movie: ('title', 'year', 'resolution', 'source',
                             'audio_format', 'video_format'),
@@ -451,12 +582,15 @@ class ReleaseName(collections.abc.Mapping):
           - :attr:`type`
           - :attr:`year`
           - :attr:`year_required`
+
+        :return: The method's instance (`self`) for convenience
         """
         await self._update_attributes(id)
         await self._update_year_required()
-        _log.debug('Release name updated: %s', self)
+        _log.debug('Release name updated with IMDb info: %s', self)
         if callback is not None:
             callback(self)
+        return self
 
     async def _update_attributes(self, id):
         info = await self._imdb.gather(
@@ -504,15 +638,15 @@ class ReleaseName(collections.abc.Mapping):
         if self.type in (ReleaseType.season, ReleaseType.episode):
             parts.append(str(self.episodes))
 
-        if self.edition:
-            parts.append(' '.join(self.edition))
-
         parts.append(self.resolution)
 
         if self.service:
             parts.append(self.service)
         parts.append(self.source)
 
+        if self.edition:
+            parts.append(' '.join(self.edition))
+
         parts.append(self.audio_format)
         if self.audio_channels:
             parts.append(self.audio_channels)
@@ -752,7 +886,13 @@ class ReleaseInfo(collections.abc.MutableMapping):
         return _as_string(self._guess.get('episode_title', ''))
 
     _edition_translation = {}
-    _edition_regex = re.compile(r'(?:[ \.]|^)((?i:proper|repack\d*))(?:[ \.]|$)')
+    _proper_repack_regex = re.compile(r'(?:[ \.]|^)((?i:proper|repack\d*))(?:[ \.]|$)')
+    _hdr_regexes = {
+        'Dolby Vision': re.compile(r'(?:[ \.]|^)(?i:DV|DoVi|Dolby[ \.]Vision)(?:[ \.]|$)'),
+        'HDR10+': re.compile(r'(?:[ \.]|^)(?i:HDR10\+)(?:[ \.]|$)'),
+        'HDR10': re.compile(r'(?:[ \.]|^)(?i:HDR10)(?:[^\+]|$)'),
+        'HDR': re.compile(r'(?:[ \.]|^)(?i:HDR)(?:[^10\+]|$)'),
+    }
 
     def _get_edition(self):
         edition = _as_list(self._guess.get('edition'))
@@ -761,18 +901,25 @@ class ReleaseInfo(collections.abc.MutableMapping):
                 if regex.search(edition[i]):
                     edition[i] = edition_fixed
 
-        # guessit doesn't distinguish between REPACK, PROPER, etc
-        match = self._edition_regex.search(self.release_name_params)
+        # Revision (guessit doesn't distinguish between REPACK, PROPER, etc)
+        match = self._proper_repack_regex.search(self.release_name_params)
         if match:
             edition.append(match.group(1).capitalize())
 
+        # Various
         guessit_other = _as_list(self._guess.get('other'))
-        if 'Dual Audio' in guessit_other:
-            edition.append('Dual Audio')
         if 'Open Matte' in guessit_other:
             edition.append('Open Matte')
         if 'Original Aspect Ratio' in guessit_other:
             edition.append('OAR')
+        if 'Dual Audio' in guessit_other:
+            edition.append('Dual Audio')
+
+        # HDR format
+        for hdr_format, regex in self._hdr_regexes.items():
+            if regex.search(self.release_name_params):
+                edition.append(hdr_format)
+                break
 
         return edition
 
